@@ -1,34 +1,23 @@
 from QuickProject import *
+from QuickProject import __latest_filename, __sub_path
 from rich.prompt import Prompt
 
-work_dir = os.getcwd()
-work_project = work_dir.split(dir_char)[-1]
-work_dir += dir_char
-lang_template = {
-    'cpp': """#include <iostream>
-using namespace std;
+templateProjectUrls = {
+    'c': ['https://github.com/Rhythmicc/QproCTemplate.git', 'QproCTemplate'],
+    'cpp': ['https://github.com/Rhythmicc/QproCppTemplate.git', 'QproCppTemplate'],
+    'java': ['https://github.com/Rhythmicc/QproJavaTemplate.git', 'QproJavaTemplate'],
+    'python3': ['https://github.com/Rhythmicc/QproPython3Template.git', 'QproPython3Template'],
+    'python': ['https://github.com/Rhythmicc/QproPythonTemplate.git', 'QproPythonTemplate']
+}
 
-int main(int argc, char **argv) {
-    cout<<"hello world\\n";
-    return 0;
-}
-""",
-    'c': """#include <stdio.h>
 
-int main(int argc, char **argv) {
-    puts("hello world");
-    return 0;
-}
-""",
-    'java': """class CLASS_NAME {
-    public static void main(String[] args) {
-        System.out.println("hello world!");
-    }
-}
-""",
-    'python': """print 'hello world'""",
-    'python3': """print('hello world')"""
-}
+def __findAndReplace(dirPath, fo, to):
+    for rt, son_dir, son_files in os.walk(dirPath):
+        for file in son_files:
+            with open(rt + dir_char + file, 'r') as f:
+                ct = f.read()
+            with open(rt + dir_char + file, 'w') as f:
+                f.write(ct.replace(fo, to))
 
 
 def remove(path):
@@ -40,14 +29,11 @@ def remove(path):
             os.remove(path)
 
 
-def scp_init(server_target: list, ct=False):
+def scp_init(server_target: list):
     if server_target:
         server, target, port = get_server_target(server_target)
         user, ip = server.split('@')
-        if ct:
-            st = SshProtocol.post_folder(user, ip, target, port, '')
-        else:
-            st = SshProtocol.post_all_in_folder(user, ip, target, port)
+        st = SshProtocol.post_all_in_folder(user, ip, target, port, '')
         if st:
             QproDefaultConsole.print(QproErrorString, "upload project failed!")
 
@@ -55,23 +41,13 @@ def scp_init(server_target: list, ct=False):
 def create():
     try:
         project_name = sys.argv[sys.argv.index('-c') + 1]
-        global work_project
-        work_project = project_name
     except IndexError:
         return QproDefaultConsole.print(QproWarnString, 'usage: Qpro -c project')
     else:
         if os.path.exists(project_name) and os.path.isdir(project_name):
-            return QproDefaultConsole.print(QproErrorString,'"%s" is exist!' % (work_dir + project_name + dir_char))
-        lang_tool_exe = {
-            'c': ['gcc -std=c11 --source_file-- -o --execute--', '', '.c'],
-            'cpp': ['g++ -std=c++11 --source_file-- -o --execute--', '', '.cpp'],
-            'java': ['javac -d dist --source_file--', 'java -classpath dist ', '.java'],
-            'python3': ['', 'python3 ', '.py'],
-            'python': ['', 'python ', '.py'],
-            'empty': ['', '', '']
-        }
+            return QproDefaultConsole.print(QproErrorString, '"%s" is exist!' % (os.path.abspath(project_name)))
         os.mkdir(project_name)
-        langs = list(lang_tool_exe.keys())
+        langs = ['c', 'cpp', 'java', 'python3', 'python', 'empty']
         for i, lang in enumerate(langs):
             QproDefaultConsole.print('[%d] %-5s' % (i + 1, lang), end='\t' if (i + 1) % 3 else '\n')
         if len(langs) % 3:
@@ -82,80 +58,68 @@ def create():
                 id_lang = int(Prompt.ask('choose one', default='6'))
             except:
                 id_lang = 0
-        lang = lang_tool_exe[langs[id_lang - 1]]
+        lang = langs[id_lang - 1]
         server_target = Prompt.ask('input user@ip:dir_path if you need scp').strip().replace(dir_char, '/')
         if server_target and not server_target.endswith('/'):
             if not server_target.endswith(':'):
                 server_target += '/'
             else:
                 server_target += '~/'
-        if not lang[-1]:
-            source_file = ''
-            execute = ''
+        if lang == 'empty':
+            with open(project_name + dir_char + 'project_configure.csv', 'w') as f:
+                for row in [
+                    ['compile_tool', ''],
+                    ['compile_filename', ''],
+                    ['executable_filename', ''],
+                    ['input_file', ''],
+                    ['template_root', ''],
+                    ['server_target', '', '']
+                ]:
+                    f.write(','.join(row) + '\n')
         else:
-            source_file = ('main' + lang[-1]) if lang[0] != 'javac' else project_name + lang[-1]
-            if lang[0] != 'javac':
-                execute = lang[1] + 'dist' + dir_char + project_name if lang[0] else lang[1] + source_file
-            else:
-                execute = lang[1] + project_name
-            with open(project_name + dir_char + source_file, 'w') as f:
-                if lang[-1] != '.other':
-                    content = lang_template[langs[id_lang - 1]]
-                    if lang[0] == 'javac':
-                        content = content.replace('CLASS_NAME', project_name)
-                    f.write(content)
-            os.mkdir(project_name + dir_char + 'dist')
-            os.mkdir(project_name + dir_char + 'template')
-        info = [
-            ['compile_tool', lang[0].replace('--source_file--', source_file).replace('--execute--', execute)],
-            ['compile_filename', source_file],
-            ['executable_filename', execute],
-            ['input_file', 'dist' + dir_char + 'input.txt' if lang[-1] else ''],
-            ['template_root', 'template' + dir_char if lang[-1] else ''],
-            ['server_target', server_target, '22' if server_target else '']
-        ]
-        with open(project_name + dir_char + 'project_configure.csv', 'w') as f:
-            for row in info:
-                f.write(','.join(row) + '\n')
-        if lang[-1]:
-            with open(project_name + dir_char + info[3][-1], 'w') as f:
-                f.write('edit this file to make input')
-            with open(project_name + dir_char + info[1][-1], 'r') as f:
-                main_cont = f.read()
-            with open(project_name + dir_char + 'template' + dir_char + 'main', 'w') as f:
-                f.write(main_cont)
-        scp_init(info[-1][1:] if server_target else None, True)
+            from git import Repo
+
+            with QproDefaultConsole.status('Cloning QPro {} Template to {}'.format(lang, project_name)):
+                Repo.clone_from(templateProjectUrls[lang][0], project_name)
+
+                os.chdir(project_name)
+                remove('.git')
+                __findAndReplace(os.getcwd(), templateProjectUrls[lang][1], project_name)
 
 
 def scp():
     try:
         path = sys.argv[sys.argv.index('-scp') + 1]
+        sub_path = __sub_path(path)
     except IndexError:
         return QproDefaultConsole.print(QproWarnString, 'usage: Qpro -scp <file>')
     else:
-        if not os.path.abspath(path).startswith(work_dir):
-            return QproDefaultConsole.print(QproErrorString, f"{path} is not in this Qpro project!")
-        if not os.path.exists(path):
-            return QproDefaultConsole.print(QproErrorString, f'No such file named: {path}')
+        if not sub_path:
+            return \
+                QproDefaultConsole.print(
+                    QproErrorString,
+                    f"{path} is not in this Qpro project!" if os.path.exists(path) else f'No such file named: {path}'
+                )
         server, target, port = get_server_target()
         user, ip = server.split('@')
         if os.path.isdir(path):
-            SshProtocol.post_folder(user, ip, target, port, path)
+            SshProtocol.post_folder(user, ip, target, port, path, sub_path)
         else:
-            SshProtocol.post_file(user, ip, target, port, path)
+            SshProtocol.post_file(user, ip, target, port, path, sub_path)
 
 
 def get():
     try:
         path = sys.argv[sys.argv.index('-get') + 1]
+        sub_path = __sub_path(path, isExist=False)
     except IndexError:
         return QproDefaultConsole.print(QproWarnString, 'usage: Qpro -get <file>')
     else:
-        if not os.path.abspath(path).startswith(work_dir):
+        if not sub_path:
             return QproDefaultConsole.print(QproErrorString, f"{path} is not in this Qpro project!")
         server, target, port = get_server_target()
         user, ip = server.split('@')
-        SshProtocol.get_file_or_folder(user, ip, target, port, path)
+        SshProtocol.get_file_or_folder(user, ip, target, port, sub_path, path)
 
 
 def adjust():
@@ -229,7 +193,7 @@ def adjust():
 def pro_init():
     id_lang = -1
     langs = []
-    if not os.path.exists('CMakeLists.txt'):
+    if not os.path.exists('cmake-build-debug'):
         global work_project
         while not work_project:
             work_project = Prompt.ask('You need to set project name').strip()
@@ -350,20 +314,21 @@ def delete_all():
 
 def delete():
     try:
-        path = sys.argv[sys.argv.index('-del') + 1]
+        path = os.path.abspath(sys.argv[sys.argv.index('-del') + 1])
+        sub_path = __sub_path(path)
     except IndexError:
         return QproDefaultConsole.print(QproWarnString, 'usage: Qpro -del <path>')
     else:
-        if not os.path.abspath(path).startswith(work_dir):
-            return QproDefaultConsole.print(QproErrorString, f"{path} is not in this Qpro project!")
-        if not os.path.exists(path):
-            return QproDefaultConsole.print(QproErrorString, f'No such file named: {path}')
+        if not sub_path:
+            return \
+                QproDefaultConsole.print(
+                    QproErrorString,
+                    f"{path} is not in this Qpro project!" if os.path.exists(path) else f'No such file named: {path}'
+                )
         config = get_config()
-        path = path.strip('.' + dir_char)
-        path = path.strip(dir_char)
         if ':' in config['server_target']:
             server, target, port = get_server_target()
-            st = os.system("ssh -p %s %s 'rm -rf %s'" % (port, server, target + path))
+            st = os.system("ssh -p %s %s 'rm -rf %s'" % (port, server, target + sub_path))
             if st:
                 return
         remove(path)
@@ -372,16 +337,14 @@ def delete():
 def tele_ls():
     try:
         path = sys.argv[sys.argv.index('-ls') + 1]
+        sub_path = __sub_path(path, False)
     except IndexError:
-        path = ''
+        sub_path = ''
     config = get_config()
-    if path:
-        path = path.strip('.' + dir_char)
-        path = path.strip(dir_char)
     if ':' in config['server_target']:
         from . import SshProtocol
         server, target, port = get_server_target()
-        os.system(f"ssh -p {port} {server} 'ls {target + path}'")
+        os.system(f"ssh -p {port} {server} 'ls {target + sub_path}'")
 
 
 func = {
